# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from __future__ import unicode_literals

import base64
from urlparse import urlparse

from django.conf import settings
from django.core.handlers.wsgi import WSGIHandler
from django.test.utils import override_settings
from lazr.restfulclient.resource import ServiceRoot
from wsgi_intercept import (
    add_wsgi_intercept,
    httplib2_intercept,
    remove_wsgi_intercept,
    urllib_intercept,
)

from identityprovider.tests.factory import SSOObjectFactory
from identityprovider.tests.utils import SSOBaseTransactionTestCase


def http_authorization_extra(email_address, password):
    email_address = base64.b64encode(b'%s:%s' % (email_address, password))
    return {'HTTP_AUTHORIZATION': 'basic ' + email_address}


@override_settings(CAPTCHA_PUBLIC_KEY='public', CAPTCHA_PRIVATE_KEY='private')
class AnonAPITestCase(SSOBaseTransactionTestCase):
    factory = SSOObjectFactory()

    def setUp(self):
        super(AnonAPITestCase, self).setUp()
        host_url = settings.SSO_ROOT_URL.rstrip('/')
        parse = urlparse(host_url)
        self.unset_env('http_proxy')
        self.unset_env('https_proxy')
        urllib_intercept.install_opener()
        self.addCleanup(urllib_intercept.uninstall_opener)
        httplib2_intercept.install()
        self.addCleanup(httplib2_intercept.uninstall)
        add_wsgi_intercept(parse.hostname, parse.port, WSGIHandler)
        self.addCleanup(remove_wsgi_intercept, parse.hostname, parse.port)
        self.api = ServiceRoot(None, host_url + '/api/1.0')

        # patch Captcha so it never hits the real network
        self.mock_captcha_open = self.patch(
            'identityprovider.models.captcha.Captcha._open')
        self.mock_captcha_open.return_value.is_error = False
        self.mock_captcha_open.return_value.data.return_value = 'true\nyey'
