# Copyright 2010-2018 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).
import functools

from api.v20.utils import errors


def is_authorized(request, edit=None):
    """Checks if logged in user has permissions based on request method.

    This helper method's main use is for keeping backwards compatibility
    with ApiOAuthAuthentication.is_authenticated().

    New API views should check permissions with @authorization_required.
    """
    if edit is None:
        edit = request.method != 'GET'
    if edit:
        perm = 'identityprovider.api_edit_account_details'
    else:
        perm = 'identityprovider.api_view_account_details'
    account = request.user
    return account.user.has_perm(perm)


def authorization_required(edit=None):
    """View decorator that checks logged in user has specific permissions."""

    def wrapper(func):
        @functools.wraps(func)
        def wrapped(self, request, *args, **kwargs):
            if not is_authorized(request, edit=edit):
                return errors.FORBIDDEN()
            return func(self, request, *args, **kwargs)

        return wrapped

    return wrapper
