# Copyright 2010-2018 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from django.conf.urls import url

from api.v20.auth import (
    ApiAccountRegistrationAuthentication,
    ApiAccountsAuthentication,
    ApiAccountsBulkAuthentication,
    ApiEmailsAuthentication,
    ApiResource,
    ApiTokensAuthentication,
)
from api.v20.handlers import (
    AccountLoginHandler,
    AccountRegistrationHandler,
    AccountsBulkHandler,
    AccountsHandler,
    EmailsHandler,
    MacaroonDischargeHandler,
    MacaroonRefreshHandler,
    PasswordResetTokenHandler,
    RequestsHandler,
    SSHKeyHandler,
    TokensHandler,
)


v2accounts = ApiResource(
    handler=AccountsHandler, authentication=ApiAccountsAuthentication())
v2accounts_bulk = ApiResource(
    handler=AccountsBulkHandler,
    authentication=ApiAccountsBulkAuthentication())
v2emails = ApiResource(
    handler=EmailsHandler, authentication=ApiEmailsAuthentication())
v2login = ApiResource(handler=AccountLoginHandler)
v2macaroon_discharge = ApiResource(handler=MacaroonDischargeHandler)
v2macaroon_refresh = ApiResource(handler=MacaroonRefreshHandler)
v2password_reset = ApiResource(handler=PasswordResetTokenHandler)
v2registration = ApiResource(
    handler=AccountRegistrationHandler,
    authentication=ApiAccountRegistrationAuthentication())
v2requests = ApiResource(handler=RequestsHandler)
v2tokens = ApiResource(
    handler=TokensHandler, authentication=ApiTokensAuthentication())
v2keys = ApiResource(handler=SSHKeyHandler)

urlpatterns = [
    url(r'^accounts$', v2registration, name='api-registration'),
    url(r'^accounts/(?P<openid>\w+)$', v2accounts, name='api-account'),
    url(r'^accounts-bulk$', v2accounts_bulk, name='api-accounts-bulk'),
    url(r'^emails/(?P<email>.+)$', v2emails, name='api-email'),
    url(r'^requests/validate$', v2requests, name='api-requests'),
    url(r'^tokens/discharge$', v2macaroon_discharge,
        name='api-macaroon-discharge'),
    url(r'^tokens/refresh$', v2macaroon_refresh, name='api-macaroon-refresh'),
    url(r'^tokens/oauth$', v2login, name='api-login'),
    url(r'^tokens/oauth/(?P<token>.+)$', v2tokens, name='api-token'),
    url(r'^tokens/password$', v2password_reset, name='api-password-reset'),
    url(r'^keys/(?P<account>.+)$', v2keys,
        {'emitter_format': 'json'}, name='api-keys'),
]
