from django.core.management.base import BaseCommand

from identityprovider.models import Account, EmailAddress


class Command(BaseCommand):

    help = ("Create or get an account with a pre-validated email to be used "
            "for automated operations.")

    def add_arguments(self, parser):
        parser.add_argument('username')
        parser.add_argument('email')
        parser.add_argument('password')

    def handle(self, *args, **options):
        name = options['username']
        email = options['email']
        password = options['password']

        try:
            email_addr = EmailAddress.objects.get(email__iexact=email)
            account = email_addr.account
        except EmailAddress.DoesNotExist:
            account = Account.objects.create_account(name, email, password,
                                                     email_validated=True)

        print("Account created with OpenID identifier: {}"
              .format(account.openid_identifier))
