from django.core.management.base import BaseCommand, CommandError

from identityprovider.models import OpenIDRPConfig


class Command(BaseCommand):
    help = "Create OpenID RP config entry."
    missing_args_message = "Need to specify trust_root"

    def add_arguments(self, parser):
        parser.add_argument(
            '--allow-unverified', action="store_true",
            default=False, dest='allow_unverified'),
        parser.add_argument(
            '--allowed-user-attribs', action="store",
            dest='allowed_user_attribs'),
        parser.add_argument(
            '--auto-authorize', action="store_true",
            default=False, dest='auto_authorize'),
        parser.add_argument(
            '--can-query-private-teams', action="store_true",
            default=False, dest='can_query_any_team'),
        parser.add_argument('trust_root')

    def handle(self, *args, **options):
        trust_root = options['trust_root']
        allow_unverified = options.get('allow_unverified', False)
        allowed_user_attribs = options.get('allowed_user_attribs', '')
        auto_authorize = options.get('auto_authorize', False)
        can_query_any_team = options.get('can_query_any_team', False)
        if allowed_user_attribs is None:
            allowed_user_attribs = ''

        try:
            rpconfig = OpenIDRPConfig.objects.get(trust_root=trust_root)
            rpconfig.allow_unverified = allow_unverified
            rpconfig.allowed_user_attribs = allowed_user_attribs
            rpconfig.auto_authorize = auto_authorize
            rpconfig.can_query_any_team = can_query_any_team
            rpconfig.save()
        except OpenIDRPConfig.DoesNotExist:
            OpenIDRPConfig.objects.create(
                trust_root=trust_root,
                allow_unverified=allow_unverified,
                allowed_user_attribs=allowed_user_attribs,
                auto_authorize=auto_authorize,
                can_query_any_team=can_query_any_team,
            )
        except OpenIDRPConfig.MultipleObjectsReturned:
            raise CommandError(
                "Multiple OpenIDRPConfig objects for trust_root '%s'"
                % trust_root)
