# Copyright 2013-2018 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from datetime import datetime

from django.core.management.base import BaseCommand

from identityprovider.utils import clean_sessions_until


class Command(BaseCommand):

    help = 'Clean sessions created until provided date.'

    def add_arguments(self, parser):
        parser.add_argument(
            '-l', '--limit', dest='limit', default=None, action='store',
            help=(
                'Number of rows to process per batch. Defaults to '
                'None, which means no limit.'))
        parser.add_argument(
            '-c', '--creation-date', dest='creation_date', action='store',
            help=(
                'Cleanup records created until this date. The format '
                'should be %Y-%m-%d'))
        parser.add_argument(
            '--dry-run', dest='dry_run', default=False, action='store_true',
            help=(
                'Do not delete for real, just '
                'print what would have been done.'))

    def handle(self, *args, **options):
        creation_date = datetime.strptime(options['creation_date'], '%Y-%m-%d')
        result = clean_sessions_until(creation_date, limit=options['limit'],
                                      dry_run=options['dry_run'])
        if result is not None:
            self.stdout.write(result)
