# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from base64 import b32encode
from urllib import quote_plus
from django import template
from django.conf import settings
from django.utils.safestring import mark_safe

register = template.Library()
URL = ('https://chart.googleapis.com/chart'
       '?chs=250x250&chld=L%%7C0&cht=qr&chl=%s')


def _encode(s):
    return b32encode(s.decode('HEX'))


@register.filter
def b32encode_hexstring(value):
    return _encode(value)


@register.simple_tag
def qrcode_url(oath_mode, ident, hex_key):
    b32_key = _encode(hex_key)
    otp_url = 'otpauth://{}/{}?secret={}'.format(oath_mode, ident, b32_key)

    if oath_mode == 'hotp':
        otp_url += '&counter=0'
    elif oath_mode == 'totp':
        otp_url += '&period={}'.format(settings.TOTP_PERIOD)

    # note: for https, you *must* use this domain
    # mark this as safe as otherwise django will urlquote our data for us
    return mark_safe(URL % quote_plus(otp_url))
