from django.core.management import CommandError, call_command
from django.test import TestCase

from identityprovider.models import EmailAddress


class AddBotAccountCommandTestCase(TestCase):

    def setUp(self):
        super(AddBotAccountCommandTestCase, self).setUp()
        self.test_email = 'webops+foo-bot@canonical.com'
        self.test_name = 'foo-bot'
        self.test_pass = 'passW0rd'

    def test_missing_arg(self):
        with self.assertRaises(CommandError) as err:
            call_command('add_bot_account', self.test_name, self.test_email)
        self.assertEqual("Error: too few arguments", str(err.exception))

    def test_extra_arg(self):
        with self.assertRaises(CommandError) as err:
            call_command('add_bot_account', self.test_name, self.test_email,
                         self.test_pass, 'somethingelse')
        self.assertEqual("Error: unrecognized arguments: somethingelse",
                         str(err.exception))

    def test_add_existing_email(self):
        call_command('add_bot_account', self.test_name,
                     self.test_email, self.test_pass)
        email = EmailAddress.objects.filter(email=self.test_email).last()

        call_command('add_bot_account', self.test_name,
                     self.test_email, self.test_pass)
        email2 = EmailAddress.objects.filter(email=self.test_email).last()

        self.assertEqual(email.account.openid_identifier,
                         email2.account.openid_identifier)

    def test_add_bot_account(self):
        call_command('add_bot_account', self.test_name,
                     self.test_email, self.test_pass)
        email = EmailAddress.objects.filter(email=self.test_email).last()
        self.assertIsNotNone(email)
        self.assertEqual(email.email, self.test_email)
        self.assertEqual(email.account.displayname, self.test_name)
