from django.core.management import CommandError, call_command

from identityprovider.models import EmailAddress
from identityprovider.models.const import AccountStatus
from identityprovider.tests.utils import SSOBaseTestCase


class SuspendAccountCommandTestCase(SSOBaseTestCase):

    def setUp(self):
        super(SuspendAccountCommandTestCase, self).setUp()
        self.test_name = 'foo-user'
        self.test_email = 'foo-user@example.com'

        self.account = self.factory.make_account(
            status=AccountStatus.ACTIVE,
            email=self.test_email,
            displayname=self.test_name,
            email_validated=True)

    def test_missing_arg(self):
        with self.assertRaises(CommandError) as err:
            call_command('suspend_account')
        self.assertEqual("Error: too few arguments", str(err.exception))

    def test_extra_arg(self):
        with self.assertRaises(CommandError) as err:
            call_command(
                'suspend_account', self.test_email, "somethingelse")
        self.assertEqual("Error: unrecognized arguments: somethingelse",
                         str(err.exception))

    def test_suspend_account(self):
        call_command('suspend_account', self.test_email)

        the_account = EmailAddress.objects.get(email=self.test_email).account
        self.assertEqual(AccountStatus.SUSPENDED, the_account.status)

    def test_suspend_account_not_found(self):
        bogusmail = "bogus" + self.test_email

        with self.assertRaises(CommandError) as err:
            call_command('suspend_account', bogusmail)
        self.assertEqual(
            "Account for email address {} not found".format(bogusmail),
            str(err.exception))
