# Copyright 2010, 2012 Canonical Ltd.  This software is licensed under
# the GNU Affero General Public License version 3 (see the file
# LICENSE).
from django.conf import settings
from django.conf.urls import include, url
from django.views.generic import RedirectView

from identityprovider.views.readonly import (
    readonly_admin,
    readonly_confirm,
    readonly_data,
)
from identityprovider.views.server import (
    cancel,
    decide,
    identity_page,
    login_by_token,
    openid_provider,
    pre_authorize,
    untrusted,
    xrds,
    xrds_identity_page,
)
from identityprovider.views.testing import (
    delegate_profile,
    error,
    openid_consumer,
)


repls = {
    'token': '(?P<token>[A-Za-z0-9]{16})/',
}

urlpatterns = [
    url(r'^\+openid$', openid_provider, name='server-openid'),
    url(r'^(?P<lang>[A-Za-z_]+)/\+openid$', openid_provider,
        name='server-openid'),
    url(r'^\+xrds$', xrds, name='server-xrds-discovery'),
    url(r'^\+id/(?P<identifier>[A-Za-z0-9\-_]+)$', identity_page,
        name='server-identity'),
    url(r'^\+id/(?P<identifier>[A-Za-z0-9\-_]+)/\+xrds$',
        xrds_identity_page, name='server-xrds'),
    url(r'^%(token)s\+decide$' % repls, decide, name='server-decide'),
    url(r'^%(token)s\+cancel$' % repls, cancel, name='cancel'),
    url(r'^%(token)s\+untrusted$' % repls, untrusted),
    url(r'\+pre-authorize-rp$', pre_authorize),
    url(r'^login_by_token$', login_by_token, name='login_by_token'),
]

urlpatterns += [
    url(r'^%(token)s$' % repls,
        RedirectView.as_view(url='/%(token)s/+decide', permanent=False)),
    url(r'^\+id/(?P<identifier>[A-Za-z0-9\-_]+)/\+index$',
        RedirectView.as_view(url='/+id/%(identifier)s', permanent=False)),
]

urlpatterns += [
    url(r'^readonly$', readonly_admin),
    url(r'^readonly/((?P<appserver>[A-Za-z0-9\-_.:]+)/)?'
        r'(?P<action>set|clear)', readonly_confirm),
    url(r'^readonlydata$', readonly_data, name='readonly-data'),
]

if settings.DEBUG:
    urlpatterns += [
        url(r'^i18n/', include('django.conf.urls.i18n')),
    ]

# if settings.TESTING is not set, these will raise 404
urlpatterns += [
    url(r'^\+openid-consumer', openid_consumer,
        name='testing-openid-consumer'),
    url(r'^~(?P<username>[A-Za-z0-9\-_]+)$',
        delegate_profile, name='testing-delegate-profile'),
    url(r'^~(?P<username>[A-Za-z0-9\-_]+)/(?P<version>[1|2])$',
        delegate_profile, name='testing-delegate-profile'),
    url(r'^error$', error, name='testing-error'),
]
