import subprocess
import unittest

from olstests import scenarii


load_tests = scenarii.load_tests_with_scenarios


class MakeTargetTestCase(unittest.TestCase):
    """Some tests are easier to write as make targets.

    This really is a shortcut and shouldn't replace more precise tests.

    Nevertheless, it's better to have such tests run as part of the regular
    test suite than having them run before or after the whole suite. Being able
    to run them as part of the test suite means they can be run concurrently
    rather than making the whole run slower.

    """

    scenarios = [(k, dict(target=k)) for k in ('lint', 'docs')]

    def test_target(self):
        make = ['make', self.target]
        try:
            subprocess.check_output(make, stderr=subprocess.STDOUT)
        except subprocess.CalledProcessError as e:
            # If at least one error is found, the exception is raised. We
            # prepend a '\n' so 'AssertionError is on a line by itself.
            self.assertEqual('', e.output, '\n' + e.output)


class MakeMigrationsTestCase(unittest.TestCase):

    def test_no_changes_detected(self):
        make = ['make', 'makemigrations', 'ARGS="--dry-run"']
        try:
            out = subprocess.check_output(make, stderr=subprocess.STDOUT)
        except subprocess.CalledProcessError as e:
            # If at least one error is found, the exception is raised. We
            # prepend a '\n' so 'AssertionError is on a line by itself.
            self.assertEqual('', e.output, '\n' + e.output)
        # Ensure developer generated all needed migrations. Will fail if there
        # are pending migrations
        self.assertIn('\nNo changes detected\n', out,
                      'There are missing migrations:\n{}'.format(out))
