# Copyright 2017 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from django import template
from django.template.base import TemplateSyntaxError
from django.template.defaulttags import (
    URLNode,
    url,
)

register = template.Library()


class URLNodeWithToken(URLNode):
    def __init__(self, token_arg, *args, **kwargs):
        self.token_arg = token_arg
        super(URLNodeWithToken, self).__init__(*args, **kwargs)

    def render(self, context):
        if self.args:
            raise TemplateSyntaxError(
                'url_with_token does not take positional arguments')
        if context.get('token') is not None:
            self.kwargs['token'] = self.token_arg
        return super(URLNodeWithToken, self).render(context)


@register.tag
def url_with_token(parser, token):
    """
    Like 'url', but adds 'token=token' if a 'token' variable is present in
    the context.
    """
    node = url(parser, token)
    token_arg = parser.compile_filter('token')
    return URLNodeWithToken(
        token_arg, node.view_name, node.args, node.kwargs, node.asvar)
